/* eslint-env jest */

const { runPlugins } = require('./helpers');

const valuePlugin_ = require('../value');
const valuePlugin = x => valuePlugin_(x, { transform: x => `token(${x})` });

it('ignores valid tokens not inside a block', () => {
  let actual = runPlugins(
    `
    $color: $color-brand;
  `,
    [valuePlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('ignores valid tokens not inside a value', () => {
  let actual = runPlugins(
    `
    .a { $color-brand: $blue; }
  `,
    [valuePlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('ignores invalid tokens', () => {
  let actual = runPlugins(
    `
    .a { color: $color-brand; }
  `,
    [valuePlugin([])]
  );
  expect(actual).toMatchSnapshot();
});

it('ignores valid tokens inside arguments', () => {
  let actual = runPlugins(
    `
    @mixin myMixin($color: $color-brand) {}
  `,
    [valuePlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('ignores valid tokens inside parentheses', () => {
  let actual = runPlugins(
    `
    ($color-brand * 2)
  `,
    [valuePlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('ignores valid tokens inside interpolation', () => {
  let actual = runPlugins(
    `
    .#{$color-brand} {}
  `,
    [valuePlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces valid tokens', () => {
  let actual = runPlugins(
    `
    .a { color: $color-brand; }
  `,
    [valuePlugin(['color-brand'])]
  );
  expect(actual).toMatchSnapshot();
});

it('replaces all valid tokens', () => {
  let actual = runPlugins(
    `
    .a { color: $color-brand-a $color-brand-b $color-brand-c; }
  `,
    [valuePlugin(['color-brand-a', 'color-brand-c'])]
  );
  expect(actual).toMatchSnapshot();
});

it('takes a transform', () => {
  let actual = runPlugins(
    `
    .a { color: $color-brand-a $color-brand-b $color-brand-c; }
  `,
    [valuePlugin_(['color-brand-a', 'color-brand-c'], { transform: x => x })]
  );
  expect(actual).toMatchSnapshot();
});
